slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPGetDimensions

Gets the number of eigenvalues to compute and the dimension of the subspace.

### Synopsis

    #include "slepcnep.h"
    PetscErrorCode NEPGetDimensions(NEP nep,PetscInt *nev,PetscInt *ncv,PetscInt *mpd)

Not Collective

### Input Parameter

| nep | - the nonlinear eigensolver context

### Output Parameters

| nev | - number of eigenvalues to compute
| ncv | - the maximum dimension of the subspace to be used by the solver
| mpd | - the maximum dimension allowed for the projected problem

### Notes

The user can specify NULL for any parameter that is not needed.

### See Also

NEPSetDimensions()

### Level

intermediate

### Location

src/nep/interface/nepopts.c

### Examples

src/nep/tutorials/ex20.c.html
src/nep/tutorials/ex20f90.F90.html
src/nep/tutorials/ex21.c.html
src/nep/tutorials/ex22.c.html
src/nep/tutorials/ex22f90.F90.html
src/nep/tutorials/ex27.c.html
src/nep/tutorials/ex27f90.F90.html
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages